using UnityEngine;
using UnityEngine.Localization;
using UnityEngine.Localization.Settings;
using DaggerfallWorkshop;
using DaggerfallWorkshop.Game;
using DaggerfallWorkshop.Game.Utility.ModSupport;
using DaggerfallWorkshop.Game.UserInterface;
using TMPro;

public class StartupScript : MonoBehaviour
{
    public static Mod mod;

    [Invoke(StateManager.StateTypes.Start, 0)]
    public static void Init(InitParams initParams)
    {
        mod = initParams.Mod;
        var go = new GameObject(mod.Title);
        go.AddComponent<StartupScript>();
    }

    void Awake()
    {
        // Load TMP font asset
        TMP_FontAsset fontAsset;
        bool result = ModManager.Instance.TryGetAsset("Alkhemikal SDF.asset", false, out fontAsset);
        if (!result)
        {
            DaggerfallUnity.LogMessage("Load Alkhemikal Font FAILED");
            return;
        }
        DaggerfallUnity.LogMessage("Load Alkhemikal Font SUCCESS");

        // Create Daggerfall font using our TMP font asset
        DaggerfallFont dfFont = new DaggerfallFont(DaggerfallFont.FontName.FONT0003);
        dfFont.UseSDFFontAsset(fontAsset);

        // Register font to default "en" locale
        Locale en = LocalizationSettings.AvailableLocales.GetLocale("en");
        if (en)
        {
            TextManager.Instance.RegisterLocalizedFont(en, DaggerfallFont.FontName.FONT0003, dfFont);
            Debug.Log("RegisterLocalizedFont completed");
        }
        else
        {
            Debug.Log("Failed to GetLocale(en)");
            return;
        }

        DaggerfallUnity.LogMessage("Alkhemikal Font Mod Completed Startup");
    }
}